@@ -2,7 +2,7 @@ from dataclasses import dataclass, field
 from typing import Optional
 
 # TODO: remove default Hydra pallets - pallets will become required parameter
-PALLETS = ["amm", "exchange", "transaction_multi_payment"]
+PALLETS = ["xyk", "exchange", "transaction_multi_payment"]
 
 
 @dataclass
